/*
Module : GeneralOptionsPropertyPage.cpp
Purpose: Implements the General options property page for EZView

Copyright (c) 2000 - 2022 by PJ Naughter (Web: www.naughter.com, Email: pjna@naughter.com)

All rights reserved.

Copyright / Usage Details:

You are allowed to include the source code in any product (commercial, shareware, freeware or otherwise)
when your product is released in binary form. You are allowed to modify the source code in any way you want
except you cannot modify the copyright details at the top of each module. If you want to distribute source
code with your application, then you are only allowed to distribute versions released by the author. This is
to maintain a single distribution point for the source code.

*/


//////////////////// Includes /////////////////////////////////////////////////

#include "stdafx.h"
#include "EZView.h"
#include "GeneralOptionsPropertyPage.h"


//////////////////// Macros / Defines /////////////////////////////////////////

#ifdef _DEBUG
#define new DEBUG_NEW
#endif //#ifdef _DEBUG


//////////////////// Implementation ///////////////////////////////////////////

#pragma warning(suppress: 26409 26433 26440 26477)
IMPLEMENT_DYNCREATE(CGeneralOptionsPropertyPage, CPropertyPage)

#pragma warning(suppress: 26455)
CGeneralOptionsPropertyPage::CGeneralOptionsPropertyPage() : CPropertyPage{CGeneralOptionsPropertyPage::IDD},
                                                             m_bPromptStartEndFolder{FALSE},
                                                             m_nSlideshowInterval{0},
                                                             m_bHideCursorDuringFullScreen{FALSE},
                                                             m_bShowFilenameDuringFullScreen{FALSE},
                                                             m_bAskMeOnDelete{FALSE},
                                                             m_BackgroundColor{RGB(0, 0, 0)},
                                                             m_TextColor{RGB(0, 255, 0)},
                                                             m_bAutoRotate{TRUE}
{
}

void CGeneralOptionsPropertyPage::DoDataExchange(CDataExchange* pDX)
{
  __super::DoDataExchange(pDX);
  DDX_Check(pDX, IDC_PROMPT_ON_START_END_FOLDER, m_bPromptStartEndFolder);
  DDX_Text(pDX, IDC_SLIDE_SHOW_INTERVAL, m_nSlideshowInterval);
  DDV_MinMaxInt(pDX, m_nSlideshowInterval, 1, 600);
  DDX_Check(pDX, IDC_HIDE_CURSOR_DURING_FULLSCREEN, m_bHideCursorDuringFullScreen);
  DDX_Check(pDX, IDC_SHOW_FILENAME_DURING_FULLSCREEN, m_bShowFilenameDuringFullScreen);
  DDX_Check(pDX, IDC_ASK_ME_ON_DELETE, m_bAskMeOnDelete);
  DDX_Control(pDX, IDC_CHOOSE_BACKGROUND, m_wndBackgroundColor);
  DDX_Control(pDX, IDC_CHOOSE_TEXTCOLOR, m_wndTextColor);
  DDX_Check(pDX, IDC_AUTO_ROTATE, m_bAutoRotate);
  if (pDX->m_bSaveAndValidate)
  {
    m_BackgroundColor = m_wndBackgroundColor.GetColor();
    m_TextColor = m_wndTextColor.GetColor();
  }
  else
  {
    m_wndBackgroundColor.SetColor(m_BackgroundColor);
    m_wndTextColor.SetColor(m_TextColor);
  }
}

#pragma warning(suppress: 26433 26440)
BEGIN_MESSAGE_MAP(CGeneralOptionsPropertyPage, CPropertyPage) //NOLINT(clang-diagnostic-unused-local-typedef, modernize-avoid-c-arrays)
END_MESSAGE_MAP()
